@@ -1,27 +1,30 @@
-use crate::logging::{ProgressBarStyle, ProgressBars};
-use crate::types::ErrBox;
+use anyhow::bail;
+use anyhow::Result;
 use std::io::Read;
 
-pub fn download_url(url: &str, progress_bars: &Option<ProgressBars>, read_env_var: impl Fn(&str) -> Option<String>) -> Result<Vec<u8>, ErrBox> {
+use crate::logging::ProgressBarStyle;
+use crate::logging::ProgressBars;
+
+pub fn download_url(url: &str, progress_bars: &Option<ProgressBars>, read_env_var: impl Fn(&str) -> Option<String>) -> Result<Vec<u8>> {
   let resp = match build_agent(url, read_env_var)?.get(url).call() {
     Ok(resp) => resp,
-    Err(err) => return err!("Error downloading {} - Error: {:?}", url, err.to_string()),
+    Err(err) => bail!("Error downloading {} - Error: {:?}", url, err.to_string()),
   };
   let total_size = {
     if resp.status() == 200 {
       resp.header("Content-Length").and_then(|s| s.parse::<usize>().ok()).unwrap_or(0)
     } else {
-      return err!("Error downloading {} - Status: {:?}", url, resp.status());
+      bail!("Error downloading {} - Status: {:?}", url, resp.status())
     }
   };
   let mut reader = resp.into_reader();
   match inner_download(url, &mut reader, total_size, progress_bars) {
     Ok(result) => Ok(result),
-    Err(err) => err!("Error downloading {} - {}", url, err.to_string()),
+    Err(err) => bail!("Error downloading {} - {}", url, err.to_string()),
   }
 }
 
-fn inner_download(url: &str, reader: &mut impl Read, total_size: usize, progress_bars: &Option<ProgressBars>) -> Result<Vec<u8>, ErrBox> {
+fn inner_download(url: &str, reader: &mut impl Read, total_size: usize, progress_bars: &Option<ProgressBars>) -> Result<Vec<u8>> {
   let mut final_bytes = Vec::with_capacity(total_size);
   if let Some(progress_bars) = &progress_bars {
     let mut buf: [u8; 512] = [0; 512]; // ensure progress bars update often
@@ -42,7 +45,7 @@ fn inner_download(url: &str, reader: &mut impl Read, total_size: usize, progress
   Ok(final_bytes)
 }
 
-fn build_agent(url: &str, read_env_var: impl Fn(&str) -> Option<String>) -> Result<ureq::Agent, ErrBox> {
+fn build_agent(url: &str, read_env_var: impl Fn(&str) -> Option<String>) -> Result<ureq::Agent> {
   let mut agent = ureq::AgentBuilder::new();
   if let Some(proxy_url) = get_proxy_url(url, read_env_var) {
     agent = agent.proxy(ureq::Proxy::new(proxy_url)?);
